"""pysentio - constants"""

NAME = "pysentio"
VERSION = "0.0.54b1"

SERIAL_READ_TIMEOUT = 2

DEFAULT_BAUD = 57600
DEFAULT_SERIALPORT = "/dev/ttyUSB1"

CONFIG = "config"
FAN = "fan"
FAN_VAL = "fan val"
GET = "get"
HEATTIMER = "heattimer"
HEATTIMER_VAL = "heattimer val"
HUMIDITY_VAL = "humidity val"
INFO = "info"
LIGHT = "light"
LIGHT_VAL = "light val"
SET = "set"
SAUNA = "sauna"
SAUNA_VAL = "sauna val"
STATUS = "status"
TEMP_BENCH_VAL = "temp-bench"
TEMP_HEATER_VAL = "temp-heater val"
TIMER = "timer"
TIMER_VAL = "timer val"
USER_PROG = "user-prog"
USER_PROG_VAL = "user-prog val"

SAUNA_RESPONSE = {
    CONFIG: "CONFIG",
    FAN: "FAN",
    FAN_VAL: "FAN",
    HEATTIMER: "HEATTIMER",
    HEATTIMER_VAL: "HEATTIMER",
    INFO: "INFO",
    LIGHT: "LIGHT",
    SAUNA: "SAUNA",
    STATUS: "STATUS",
    TIMER: "timer",
    TIMER_VAL: "timer",
    TEMP_BENCH_VAL: "TEMP-BENCH",
    TEMP_HEATER_VAL: "TEMP-HEATER",
    USER_PROG: "USER-PROG",
    USER_PROG_VAL: "USER-PROG",
}



import setuptools
import codecs
import re
import os

with open("README.md", "r") as fh:
    long_description = fh.read()

here = os.path.abspath(os.path.dirname(__file__))


def read(*parts):
    with codecs.open(os.path.join(here, *parts), "r") as fp:
        return fp.read()


def find_version(*file_paths):
    version_file = read(*file_paths)
    version_match = re.search(r"^VERSION = ['\"]([^'\"]*)['\"]", version_file, re.M)
    if version_match:
        return version_match.group(1)
    raise RuntimeError("Unable to find version string.")


setuptools.setup(
    name="pysentio",
    version=find_version("pysentio", "const.py"),
    author="Ake Strandberg",
    author_email="ake@strandberg.eu",
    description="Python library for Sentio Pro Sauna Controller",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/astrandb/pysentio",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        "Development Status :: 4 - Beta",
    ],
    python_requires=">=3.12",
    install_requires=["pyserial>=3.4"],
)
